package jalview.ext.archaeopteryx;

import jalview.analysis.TreeBuilder;
import jalview.datamodel.SequenceI;
import jalview.ext.forester.ForesterMatrix;
import jalview.util.MessageManager;

import org.forester.evoinference.distance.NeighborJoiningF;
import org.forester.evoinference.matrix.distance.DistanceMatrix;
import org.forester.phylogeny.Phylogeny;
import org.forester.phylogeny.PhylogenyNode;

public class ArchaeopteryxTreeConverter
{
  protected final SequenceI[] sequences;

  private Phylogeny aptxTree;

  private PhylogenyNode rootNode;

  protected final DistanceMatrix distances;
  
  protected final TreeBuilder jalviewTree;
  
  public String treeTitle;



  public ArchaeopteryxTreeConverter(final TreeBuilder calculatedTree)
  {
    jalviewTree = calculatedTree;
    sequences = jalviewTree.getSequences();
    distances = ForesterMatrix.convertJalviewToForester(
            jalviewTree.testDistances, sequences);
    aptxTree = new Phylogeny();
    rootNode = new PhylogenyNode();

  }

  public Phylogeny buildAptxTree(final PhylogenyNode treeRoot)
  {

    rootNode = treeRoot;

    buildAptxTree();


    return aptxTree;

  }

  public Phylogeny buildAptxTree()
  {

    NeighborJoiningF foresterClustering = NeighborJoiningF
            .createInstance();
    aptxTree = foresterClustering.execute(distances);
    treeTitle = generateTreeName();
    aptxTree.setName(treeTitle);

    return aptxTree;

  }

  private Phylogeny clusterNodes()
  {
    return aptxTree;

  }


  /**
   * Formats a localised title for the tree panel, like
   * <p>
   * Neighbour Joining Using BLOSUM62
   * <p>
   * For a tree loaded from file, just uses the file name
   * 
   * @return
   */
  public String generateTreeName()
  {
    if (treeTitle != null) // will currently never happen, loaded tree file will
                           // take a different path
    {
      return treeTitle;
    }
    else
    {
      /*
      * i18n description of Neighbour Joining or Average Distance method
      */
      String treecalcnm = MessageManager
              .getString("label.tree_calc_" + jalviewTree.getClass()
                      .getSimpleName().substring(0, 2).toLowerCase());
      /*
      * short score model name (long description can be too long)
      */
      String smn = jalviewTree.getScoreModel().getName();

      /*
      * put them together as <method> Using <model>
      */
      final String ttl = MessageManager
              .formatMessage("label.treecalc_title", treecalcnm, smn);
      return ttl;
    }
  }
}
